galapagos -- From Sanderson 2000, cited by Griffith et al. 2016
mushrooms -- From UCI ML 1987, on Kaggle
pokemon -- From Banik 2017 on Kaggle
cmudict -- From CMUdict (version 0.7b) 2014, adapted
wiktionary -- Data from Wiktionary, collected by Tresoldi (2018)
toy -- Data for quick testing
